==> jc-1.4.0.tar.gz: soot/jimple/spark/pag/LocalVarNode.h <==
// public class soot.jimple.spark.pag.LocalVarNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 271d8e0f2f41c14 soot_jimple_spark_pag_LocalVarNode
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node
// @dep_class 8f994f8885f1a8b4 soot_jimple_spark_pag_ValNode
// @dep_class 50497b61bb8d76a8 soot_jimple_spark_pag_VarNode

// header file dependencies
// @dep_header soot_jimple_spark_pag_VarNode

#include "soot/jimple/spark/pag/VarNode.h"

#ifndef _JC_soot_jimple_spark_pag_LocalVarNode_H_
#define _JC_soot_jimple_spark_pag_LocalVarNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_pag_ContextVarNode$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_LocalVarNode$sub_refs	_jc_soot_jimple_spark_pag_LocalVarNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_LocalVarNode$sub_nonrefs	_jc_soot_jimple_spark_pag_LocalVarNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_LocalVarNode$refs	_jc_soot_jimple_spark_pag_LocalVarNode$refs;
typedef struct _jc_soot_jimple_spark_pag_LocalVarNode$nonrefs	_jc_soot_jimple_spark_pag_LocalVarNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_LocalVarNode$object	_jc_soot_jimple_spark_pag_LocalVarNode$object;

typedef const struct _jc_soot_jimple_spark_pag_LocalVarNode$vmethods	_jc_soot_jimple_spark_pag_LocalVarNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_LocalVarNode$vtable	_jc_soot_jimple_spark_pag_LocalVarNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_LocalVarNode$vtype	_jc_soot_jimple_spark_pag_LocalVarNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_LocalVarNode$method$_init$41b3d87c50ccf35a(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_java_lang_Object$object *, struct _jc_soot_Type$object *, struct _jc_soot_SootMethod$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_pag_LocalVarNode$method$addContext$46a02143dc8c6311(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *, struct _jc_soot_jimple_spark_pag_ContextVarNode$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_soot_jimple_spark_pag_ContextVarNode$object *_jc_soot_jimple_spark_pag_LocalVarNode$method$context$f388a57be1d8849a(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_spark_pag_LocalVarNode$method$getMethod$04d7c221deab35ce(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_LocalVarNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_LocalVarNode$method_info$addContext$46a02143dc8c6311;
extern _jc_method _jc_soot_jimple_spark_pag_LocalVarNode$method_info$context$f388a57be1d8849a;
extern _jc_method _jc_soot_jimple_spark_pag_LocalVarNode$method_info$getMethod$04d7c221deab35ce;
extern _jc_method _jc_soot_jimple_spark_pag_LocalVarNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_LocalVarNode$vmethods {
	void	(*addContext$46a02143dc8c6311)(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *, struct _jc_soot_jimple_spark_pag_ContextVarNode$object *, struct _jc_java_lang_Object$object *);
	struct _jc_soot_jimple_spark_pag_ContextVarNode$object	*(*context$f388a57be1d8849a)(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *, struct _jc_java_lang_Object$object *);
	struct _jc_soot_SootMethod$object	*(*getMethod$04d7c221deab35ce)(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *);
};

// Vtable
struct _jc_soot_jimple_spark_pag_LocalVarNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_ValNode$vmethods	soot_jimple_spark_pag_ValNode;
	_jc_soot_jimple_spark_pag_VarNode$vmethods	soot_jimple_spark_pag_VarNode;
	_jc_soot_jimple_spark_pag_LocalVarNode$vmethods	soot_jimple_spark_pag_LocalVarNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_LocalVarNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_LocalVarNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_LocalVarNode$sub_refs {
	struct _jc_object	*cvns;
	struct _jc_soot_SootMethod$object	*method;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_LocalVarNode$refs {
    _jc_soot_jimple_spark_pag_LocalVarNode$sub_refs	soot_jimple_spark_pag_LocalVarNode;
    _jc_soot_jimple_spark_pag_VarNode$sub_refs	soot_jimple_spark_pag_VarNode;
    _jc_soot_jimple_spark_pag_ValNode$sub_refs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_LocalVarNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_LocalVarNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_ValNode$sub_nonrefs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_VarNode$sub_nonrefs	soot_jimple_spark_pag_VarNode;
    _jc_soot_jimple_spark_pag_LocalVarNode$sub_nonrefs	soot_jimple_spark_pag_LocalVarNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_LocalVarNode$object {
	_jc_soot_jimple_spark_pag_LocalVarNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_LocalVarNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_LocalVarNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_LocalVarNode$vtype _jc_soot_jimple_spark_pag_LocalVarNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_LocalVarNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_LocalVarNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_LocalVarNode_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/pag/LocalVarNode.h <==
// public class soot.jimple.spark.pag.LocalVarNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 271d8e0f2f41c14 soot_jimple_spark_pag_LocalVarNode
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node
// @dep_class 8f994f8885f1a8b4 soot_jimple_spark_pag_ValNode
// @dep_class 50497b61bb8d76a8 soot_jimple_spark_pag_VarNode

// header file dependencies
// @dep_header soot_jimple_spark_pag_VarNode

#include "soot/jimple/spark/pag/VarNode.h"

#ifndef _JC_soot_jimple_spark_pag_LocalVarNode_H_
#define _JC_soot_jimple_spark_pag_LocalVarNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_pag_ContextVarNode$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_LocalVarNode$sub_refs	_jc_soot_jimple_spark_pag_LocalVarNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_LocalVarNode$sub_nonrefs	_jc_soot_jimple_spark_pag_LocalVarNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_LocalVarNode$refs	_jc_soot_jimple_spark_pag_LocalVarNode$refs;
typedef struct _jc_soot_jimple_spark_pag_LocalVarNode$nonrefs	_jc_soot_jimple_spark_pag_LocalVarNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_LocalVarNode$object	_jc_soot_jimple_spark_pag_LocalVarNode$object;

typedef const struct _jc_soot_jimple_spark_pag_LocalVarNode$vmethods	_jc_soot_jimple_spark_pag_LocalVarNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_LocalVarNode$vtable	_jc_soot_jimple_spark_pag_LocalVarNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_LocalVarNode$vtype	_jc_soot_jimple_spark_pag_LocalVarNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_LocalVarNode$method$_init$41b3d87c50ccf35a(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_java_lang_Object$object *, struct _jc_soot_Type$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_pag_LocalVarNode$method$addContext$46a02143dc8c6311(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *, struct _jc_soot_jimple_spark_pag_ContextVarNode$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_spark_pag_ContextVarNode$object *_jc_soot_jimple_spark_pag_LocalVarNode$method$context$f388a57be1d8849a(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_spark_pag_LocalVarNode$method$getMethod$04d7c221deab35ce(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_LocalVarNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_LocalVarNode$method_info$addContext$46a02143dc8c6311;
extern _jc_method _jc_soot_jimple_spark_pag_LocalVarNode$method_info$context$f388a57be1d8849a;
extern _jc_method _jc_soot_jimple_spark_pag_LocalVarNode$method_info$getMethod$04d7c221deab35ce;
extern _jc_method _jc_soot_jimple_spark_pag_LocalVarNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_LocalVarNode$vmethods {
	void	(*addContext$46a02143dc8c6311)(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *, struct _jc_soot_jimple_spark_pag_ContextVarNode$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_spark_pag_ContextVarNode$object	*(*context$f388a57be1d8849a)(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_soot_SootMethod$object	*(*getMethod$04d7c221deab35ce)(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_LocalVarNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_pag_LocalVarNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_ValNode$vmethods	soot_jimple_spark_pag_ValNode;
	_jc_soot_jimple_spark_pag_VarNode$vmethods	soot_jimple_spark_pag_VarNode;
	_jc_soot_jimple_spark_pag_LocalVarNode$vmethods	soot_jimple_spark_pag_LocalVarNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_LocalVarNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_LocalVarNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_LocalVarNode$sub_refs {
	struct _jc_object	*cvns;
	struct _jc_soot_SootMethod$object	*method;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_LocalVarNode$refs {
    _jc_soot_jimple_spark_pag_LocalVarNode$sub_refs	soot_jimple_spark_pag_LocalVarNode;
    _jc_soot_jimple_spark_pag_VarNode$sub_refs	soot_jimple_spark_pag_VarNode;
    _jc_soot_jimple_spark_pag_ValNode$sub_refs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_LocalVarNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_LocalVarNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_ValNode$sub_nonrefs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_VarNode$sub_nonrefs	soot_jimple_spark_pag_VarNode;
    _jc_soot_jimple_spark_pag_LocalVarNode$sub_nonrefs	soot_jimple_spark_pag_LocalVarNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_LocalVarNode$object {
	_jc_soot_jimple_spark_pag_LocalVarNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_LocalVarNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_LocalVarNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_LocalVarNode$vtype _jc_soot_jimple_spark_pag_LocalVarNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_LocalVarNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_LocalVarNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_LocalVarNode_H_ */
